defusedxml: Addresses vulnerabilities of XML parsers and XML libraries
======================================================================

Description
-----------

defusedxml addresses vulnerabilities of XML parsers and XML libraries.

It became a dependency of nbconvert starting with nbconvert 5.4.

License
-------

Python Software Foundation License (PSFL)


Upstream Contact
----------------

https://pypi.org/project/defusedxml/

Special Update/Build Instructions
---------------------------------

None.
